==> cl_appbase-0.0.35.tar.gz: lib/src/api/api_resource.dart <==
import 'package:cl_appbase/api.dart';
import 'package:cl_datahub_common/common.dart';

class ApiResource<TData extends TransferObject> {
  final String endpointSuffix;
  final DTOFactory<TData> factory;
  final ApiBase api;

  const ApiResource._(this.api, this.endpointSuffix, this.factory);
}

class ListApiResource<TData extends TransferObject, TId>
    extends ApiResource<TData> {
  const ListApiResource(
      ApiBase api, String endpointSuffix, DTOFactory<TData> factory)
      : super._(api, endpointSuffix, factory);

  Future<List<TData>> getList(int offset, int limit,
      {Map<String, dynamic>? params, Map<String, String>? query}) async {
    final response = await api.getList<TData>(endpointSuffix,
        urlParams: params,
        query: {
          'offset': offset.toString(),
          'limit': limit.toString(),
          if (query != null) ...query
        },
        factory: factory);
    response.throwOnError();
    return response.data;
  }

  Future<TData> getElement(TId id,
      {Map<String, dynamic>? params, Map<String, String>? query}) async {
    final response = await api.getObject('$endpointSuffix/$id',
        urlParams: params, factory: factory, query: query);
    response.throwOnError();
    return response.data;
  }

  Future<TData> postElement(TData element,
      {Map<String, dynamic>? params, Map<String, String>? query}) async {
    final response = await api.postObject(endpointSuffix, element,
        urlParams: params, query: query, factory: factory);
    response.throwOnError();
    return response.data;
  }

  Future<TData> putElement(TData element,
      {Map<String, dynamic>? params, Map<String, String>? query}) async {
    final url =
        element is IntIdTransferObject || element is StringIdTransferObject
            ? '$endpointSuffix/${(element as dynamic).id}'
            : endpointSuffix;
    final response = await api.putObject(url, element,
        urlParams: params, factory: factory, query: query);
    response.throwOnError();
    return response.data;
  }

  Future<TData> patchElement(TData element,
      {Map<String, dynamic>? params, Map<String, String>? query}) async {
    final url =
        element is IntIdTransferObject || element is StringIdTransferObject
            ? '$endpointSuffix/${(element as dynamic).id}'
            : endpointSuffix;
    final response = await api.patchObject(url, element,
        urlParams: params, factory: factory, query: query);
    response.throwOnError();
    return response.data;
  }

  Future<void> deleteElement(TId id,
      {Map<String, dynamic>? params, Map<String, String>? query}) async {
    final response = await api.delete('$endpointSuffix/$id',
        urlParams: params, query: query);
    response.throwOnError();
  }
}

class SingleObjectApiResource<TData extends TransferObject>
    extends ApiResource<TData> {
  const SingleObjectApiResource(
      ApiBase api, String endpointSuffix, DTOFactory<TData> factory)
      : super._(api, endpointSuffix, factory);

  Future<TData> getElement(
      {Map<String, dynamic>? params, Map<String, String>? query}) async {
    final response = await api.getObject('$endpointSuffix',
        urlParams: params, factory: factory);
    response.throwOnError();
    return response.data;
  }

  Future<TData> postElement(TData element,
      {Map<String, dynamic>? params, Map<String, String>? query}) async {
    final response = await api.postObject(endpointSuffix, element,
        urlParams: params, factory: factory);
    response.throwOnError();
    return response.data;
  }

  Future<TData> putElement(TData element,
      {Map<String, dynamic>? params, Map<String, String>? query}) async {
    final response = await api.putObject(endpointSuffix, element,
        urlParams: params, factory: factory);
    response.throwOnError();
    return response.data;
  }

  Future<TData> patchElement(TData element,
      {Map<String, dynamic>? params, Map<String, String>? query}) async {
    final response = await api.patchObject(endpointSuffix, element,
        urlParams: params, factory: factory);
    response.throwOnError();
    return response.data;
  }
}

==> cl_appbase-0.0.46.tar.gz: lib/src/api/api_resource.dart <==
import 'package:cl_appbase/api.dart';
import 'package:cl_datahub_common/common.dart';

class ApiResource<TData extends TransferObject> {
  final String endpointSuffix;
  final DTOFactory<TData> factory;
  final ApiBase api;

  const ApiResource._(this.api, this.endpointSuffix, this.factory);
}

class ListApiResource<TData extends TransferObject, TId>
    extends ApiResource<TData> {
  const ListApiResource(
      ApiBase api, String endpointSuffix, DTOFactory<TData> factory)
      : super._(api, endpointSuffix, factory);

  Future<List<TData>> getList(int offset, int limit,
      {Map<String, dynamic>? params, Map<String, String?>? query}) async {
    final response = await api.getList<TData>(endpointSuffix,
        urlParams: params,
        query: {
          'offset': offset.toString(),
          'limit': limit.toString(),
          if (query != null) ...query
        },
        factory: factory);
    response.throwOnError();
    return response.data;
  }

  Future<TData> getElement(TId id,
      {Map<String, dynamic>? params, Map<String, String?>? query}) async {
    final response = await api.getObject('$endpointSuffix/$id',
        urlParams: params, factory: factory, query: query);
    response.throwOnError();
    return response.data;
  }

  Future<TData> postElement(TData element,
      {Map<String, dynamic>? params, Map<String, String?>? query}) async {
    final response = await api.postObject(endpointSuffix, element,
        urlParams: params, query: query, factory: factory);
    response.throwOnError();
    return response.data;
  }

  Future<TData> putElement(TData element,
      {Map<String, dynamic>? params, Map<String, String?>? query}) async {
    final url =
        element is IntIdTransferObject || element is StringIdTransferObject
            ? '$endpointSuffix/${(element as dynamic).id}'
            : endpointSuffix;
    final response = await api.putObject(url, element,
        urlParams: params, factory: factory, query: query);
    response.throwOnError();
    return response.data;
  }

  Future<TData> patchElement(TData element,
      {Map<String, dynamic>? params, Map<String, String?>? query}) async {
    final url =
        element is IntIdTransferObject || element is StringIdTransferObject
            ? '$endpointSuffix/${(element as dynamic).id}'
            : endpointSuffix;
    final response = await api.patchObject(url, element,
        urlParams: params, factory: factory, query: query);
    response.throwOnError();
    return response.data;
  }

  Future<void> deleteElement(TId id,
      {Map<String, dynamic>? params, Map<String, String?>? query}) async {
    final response = await api.delete('$endpointSuffix/$id',
        urlParams: params, query: query);
    response.throwOnError();
  }
}

class SingleObjectApiResource<TData extends TransferObject>
    extends ApiResource<TData> {
  const SingleObjectApiResource(
      ApiBase api, String endpointSuffix, DTOFactory<TData> factory)
      : super._(api, endpointSuffix, factory);

  Future<TData> getElement(
      {Map<String, dynamic>? params, Map<String, String?>? query}) async {
    final response = await api.getObject('$endpointSuffix',
        urlParams: params, factory: factory);
    response.throwOnError();
    return response.data;
  }

  Future<TData> postElement(TData element,
      {Map<String, dynamic>? params, Map<String, String?>? query}) async {
    final response = await api.postObject(endpointSuffix, element,
        urlParams: params, factory: factory);
    response.throwOnError();
    return response.data;
  }

  Future<TData> putElement(TData element,
      {Map<String, dynamic>? params, Map<String, String?>? query}) async {
    final response = await api.putObject(endpointSuffix, element,
        urlParams: params, factory: factory);
    response.throwOnError();
    return response.data;
  }

  Future<TData> patchElement(TData element,
      {Map<String, dynamic>? params, Map<String, String?>? query}) async {
    final response = await api.patchObject(endpointSuffix, element,
        urlParams: params, factory: factory);
    response.throwOnError();
    return response.data;
  }
}
